[![Build Status](https://img.shields.io/pypi/v/pytonik_time_ago)](https://pypi.python.org/pypi/pytonik_time_ago)
[![Downloads](https://img.shields.io/pypi/dm/pytonik_time_ago)](https://pypi.python.org/pypi/pytonik_time_ago/)
[![Wheel](https://img.shields.io/pypi/wheel/pytonik_time_ago.svg)](https://pypi.python.org/pypi/pytonik_time_ago)
[![Python Version](https://img.shields.io/pypi/pyversions/pytonik_time_ago)](https://pypi.python.org/pypi/pytonik-agent)
[![License](https://img.shields.io/pypi/l/pytonik_time_ago)](https://pypi.python.org/pypi/pytonik_time_ago)

# pytonik Time Ago Module
[pytonik](https://pypi.python.org/pypi/pytonik) Time Ago Module, convert date and time to human readable format

## Install pytonik time ago
```
pip install pytonik_time_ago

```
## Import Module
```
from pytonik_time_ago.timeago import timeago
```

### default 
```
timeago("2019-11-25 18:07:10").ago
```

### format 

```
timeago("19-11-2019 18:07:10", '%d-%m-%Y %H:%M:%S').ago
```

pytonik is open to questions and contributions, feel free to ask.

## Contact Information:

**Name:**  pytonik MVC

**Email:** pytonikmvc@gmail.com
